import{_ as C}from"./logo.084e5d7c.js";import{v as I,b as r,ev as y,eE as B,eF as w,e as h,d as k,eA as L,a as D,u as e,c,bg as S,w as t,f as o,aq as l,eD as i,bO as f,cC as b,cy as N,eL as V,eC as E,f2 as R,bq as T,ex as q}from"./outputWidgets.3c34606b.js";import{b as g}from"./router.56692652.js";import{a as F}from"./asyncComputed.8707f293.js";import{A as P}from"./Text.aa4a1cf1.js";import{A as $,B as j,a as H,c as M}from"./index.5da6d53a.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[s]="e97bb053-717f-41c7-a719-78350956b7b1",a._sentryDebugIdIdentifier="sentry-dbid-e97bb053-717f-41c7-a719-78350956b7b1")}catch{}})();const O={},v=a=>(B("data-v-439be421"),a=a(),w(),a),U={class:"logo"},z=v(()=>h("img",{class:"logo-img",src:C,alt:"Abstra cloud logo"},null,-1)),G=v(()=>h("span",null,"Abstra Cloud",-1)),J=[z,G];function K(a,s){return r(),y("div",U,J)}const Q=I(O,[["render",K],["__scopeId","data-v-439be421"]]),W=k({__name:"LoginBlock",setup(a){function s(p){const m=p.split("@")[0];return V.exports.kebabCase(m).toUpperCase().split("-").slice(0,2).map(d=>d[0]).join("")}const u=L(),{result:n,loading:_,refetch:A}=F(async()=>g.getAuthor());function x(){g.removeAuthor(),A(),u.push({name:"login"})}return(p,m)=>{const d=D("router-link");return e(_)?(r(),c(e(S),{key:0})):e(n)?(r(),c(e(N),{key:1,placement:"bottomRight"},{content:t(()=>[o(e(b),{direction:"vertical"},{default:t(()=>[o(e(P),null,{default:t(()=>[l(i(e(n).claims.email),1)]),_:1}),o(e(f),{onClick:x},{default:t(()=>[l("Logout")]),_:1})]),_:1})]),default:t(()=>[o(e(b),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[o(e($),null,{default:t(()=>[l(i(s(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(r(),c(e(f),{key:2},{default:t(()=>[o(d,{to:"/login"},{default:t(()=>[l("Login")]),_:1})]),_:1}))}}}),oe=k({__name:"Navbar",props:{breadcrumb:{}},setup(a){return(s,u)=>(r(),c(e(M),{style:{padding:"5px 25px"}},{breadcrumb:t(()=>[s.breadcrumb?(r(),c(e(j),{key:0},{default:t(()=>[(r(!0),y(T,null,E(s.breadcrumb,(n,_)=>(r(),c(e(H),{key:_},{default:t(()=>[o(e(R),{to:n.path},{default:t(()=>[l(i(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):q("",!0)]),title:t(()=>[o(Q)]),extra:t(()=>[o(W)]),_:1}))}});export{oe as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.b6cbd5f9.js.map
