import{d,eB as b,G as p,a as g,b as f,c as v,w as r,f as s}from"./outputWidgets.3c34606b.js";import{B as _}from"./BaseLayout.0cad2a63.js";import{a as h}from"./asyncComputed.8707f293.js";import"./router.56692652.js";import"./index.c3f2d302.js";import{P as z}from"./project.d605460b.js";import{O as y}from"./organization.8d89f32c.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.b6cbd5f9.js";import{S as I}from"./Sidebar.9cef7ab7.js";import{e as w,L as O,M as C,N as B,O as P,P as k,q as L,Q as $,s as M,G as N,H as S,I as x}from"./icons.e6ec075a.js";import"./FormItem.895a8678.js";import"./hasIn.01f4de81.js";import"./index.dd5bce3f.js";import"./index.cf4c23b9.js";import"./record.c46cf28f.js";import"./pubsub.28c1e0e3.js";import"./logo.084e5d7c.js";import"./Text.aa4a1cf1.js";import"./index.5da6d53a.js";import"./index.507e77a0.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="0c24c433-89f2-4ecc-92f9-5b5462bb5609",o._sentryDebugIdIdentifier="sentry-dbid-0c24c433-89f2-4ecc-92f9-5b5462bb5609")}catch{}})();const oa=d({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=h(()=>z.get(c).then(async e=>{const t=await y.get(e.organizationId);return{project:e,organization:t}})),m=p(()=>{var e,t,n,l;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(l=a.value)==null?void 0:l.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=p(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:w},{name:"Builds",path:"builds",icon:O},{name:"Connectors",path:"connectors",icon:C,unavailable:!a.value.organization.featureFlags.CONNECTORS_CONSOLE},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:k},{name:"Files",path:"files",icon:L},{name:"Logs",icon:$,path:"logs"},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:N,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:S,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:x,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=g("router-view");return f(),v(_,null,{content:r(()=>[s(n)]),navbar:r(()=>[s(j,{class:"nav",breadcrumb:m.value},null,8,["breadcrumb"])]),sidebar:r(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{oa as default};
//# sourceMappingURL=Project.5d3e2331.js.map
