import{cw as r}from"./outputWidgets.3c34606b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="0aa639b0-c8e5-42fd-87d6-3a8e5780df4d",e._sentryDebugIdIdentifier="sentry-dbid-0aa639b0-c8e5-42fd-87d6-3a8e5780df4d")}catch{}})();const t=(e,d)=>{r.error({message:e,description:d})};export{t as p};
//# sourceMappingURL=popupNotifcation.11fa3053.js.map
