import{N as f}from"./NavbarControls.ad5eabf1.js";import{d as _,eA as b,eB as y,G as g,a as v,b as c,ev as h,f as e,w as s,u as r,e as k,bq as w,aq as x,c as S,eU as q,v as T}from"./outputWidgets.3c34606b.js";import{A}from"./Text.aa4a1cf1.js";import{T as B,A as o}from"./TabPane.71fe903b.js";import{c as C}from"./index.5da6d53a.js";import"./asyncComputed.8707f293.js";import"./index.8371fc8b.js";import"./pubsub.28c1e0e3.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.36eacc0b.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.0a71f3ea.js";import"./ant-design.8f4f3ad4.js";import"./index.5cd5e321.js";import"./Modal.10b1f4fc.js";import"./Link.84770fdd.js";import"./index.b57ed653.js";import"./Title.f4855332.js";import"./index.1ccc96af.js";import"./workspaces.aec95309.js";import"./record.c46cf28f.js";import"./url.425cd9cb.js";import"./popupNotifcation.11fa3053.js";import"./CircularLoading.792dec2b.js";import"./icons.e6ec075a.js";import"./index.75fc5b93.js";import"./hasIn.01f4de81.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="d6037ec8-f0d8-40de-8c28-da303f146db3",a._sentryDebugIdIdentifier="sentry-dbid-d6037ec8-f0d8-40de-8c28-da303f146db3")}catch{}})();const I={class:"content"},D=_({__name:"Settings",setup(a){const t=b(),n=y();function d(){t.push({name:"home"})}const m=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function p(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const u=v("router-view");return c(),h(w,null,[e(r(C),{style:{padding:"5px 25px"},onBack:d},{extra:s(()=>[e(f,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(r(A),null,{default:s(()=>[x("Settings")]),_:1})]),footer:s(()=>[e(r(B),{"active-key":m.value,onChange:p},{default:s(()=>[e(r(o),{key:"style",tab:"Style"}),e(r(o),{key:"sidebar",tab:"Sidebar"}),e(r(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",I,[e(u,null,{default:s(({Component:l})=>[(c(),S(q(l)))]),_:1})])],64)}}});const ae=T(D,[["__scopeId","data-v-772f4b10"]]);export{ae as default};
//# sourceMappingURL=Settings.982a69e4.js.map
