import{v as r,a as o,b as i,c as d,i as c,T as p,j as u,P as _,C as f,M as l,s as g,k as s,l as m,m as b,n as y,p as v}from"./outputWidgets.3c34606b.js";import{u as w,s as h,a}from"./index.8371fc8b.js";import"./pubsub.28c1e0e3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d5aabda8-f1e9-46d6-b767-3eca2f484639",e._sentryDebugIdIdentifier="sentry-dbid-d5aabda8-f1e9-46d6-b767-3eca2f484639")}catch{}})();const I={};function k(e,t){const n=o("router-view");return i(),d(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=r(I,[["render",k]]);class P{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await Promise.all([w(),h()]);const e=c({render:()=>m(x)});p.init(),u(e,a),P.init(),e.use(a),e.use(_),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",l),e.component("Message",g),s(e,b),s(e,y),s(e,v)})();
//# sourceMappingURL=player.d80734af.js.map
