import{C as t,E as d,K as i,a as f,M as b,c as l,P as y,R as c,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.adc62b0c.js";import"./outputWidgets.3c34606b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="6466ebad-3599-4f8e-9df6-8e88be0259ff",e._sentryDebugIdIdentifier="sentry-dbid-6466ebad-3599-4f8e-9df6-8e88be0259ff")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,f as KeyMod,b as MarkerSeverity,l as MarkerTag,y as Position,c as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.3c7c30c2.js.map
