import{S as p}from"./Sidebar.9cef7ab7.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.b6cbd5f9.js";import{G as d,H as l,I as u}from"./icons.e6ec075a.js";import{d as b,eB as f,G as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.3c34606b.js";import{a as w}from"./asyncComputed.8707f293.js";import"./router.56692652.js";import"./index.c3f2d302.js";import{O as z}from"./organization.8d89f32c.js";import{B as I}from"./BaseLayout.0cad2a63.js";import"./index.507e77a0.js";import"./logo.084e5d7c.js";import"./Text.aa4a1cf1.js";import"./index.5da6d53a.js";import"./FormItem.895a8678.js";import"./hasIn.01f4de81.js";import"./index.dd5bce3f.js";import"./index.cf4c23b9.js";import"./record.c46cf28f.js";import"./pubsub.28c1e0e3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f20adbc5-8ce1-4e0d-9a58-5f795e4e8520",e._sentryDebugIdIdentifier="sentry-dbid-f20adbc5-8ce1-4e0d-9a58-5f795e4e8520")}catch{}})();const F=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(h,B)=>{const m=_("router-view");return y(),v(I,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{F as default};
//# sourceMappingURL=Organization.0682b13e.js.map
