import{F as t}from"./Form.d74c49d4.js";import{aL as d,cl as n}from"./outputWidgets.3c34606b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d5160082-dbbe-49cc-b12d-c1a9ebe55559",e._sentryDebugIdIdentifier="sentry-dbid-d5160082-dbbe-49cc-b12d-c1a9ebe55559")}catch{}})();t.useInjectFormItemContext=d;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.743320c6.js.map
