import{C as n,A as t}from"./CollapsePanel.66387f75.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="60ecc828-1da9-44c3-952f-70f8e513a0b5",e._sentryDebugIdIdentifier="sentry-dbid-60ecc828-1da9-44c3-952f-70f8e513a0b5")}catch{}})();n.Panel=t;n.install=function(e){return e.component(n.name,n),e.component(t.name,t),e};
//# sourceMappingURL=index.50f50955.js.map
