import{U as s}from"./outputWidgets.3c34606b.js";import{c as i,d}from"./index.a9648604.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="9c59c666-6a3e-423c-8c11-e63bfbdd21c8",e._sentryDebugIdIdentifier="sentry-dbid-9c59c666-6a3e-423c-8c11-e63bfbdd21c8")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:c,RangePicker:o}=i(d),y=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:c,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(c.name,c),e)});export{y as D,t as M,c as Q,o as R,r as W};
//# sourceMappingURL=dayjs.b13d1b80.js.map
