import{v as t,b as s,ev as a}from"./outputWidgets.3c34606b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="44ad49d0-17e2-4432-bae8-2c67db0ac582",e._sentryDebugIdIdentifier="sentry-dbid-44ad49d0-17e2-4432-bae8-2c67db0ac582")}catch{}})();const d={},o={class:"organization-settings"};function r(e,n){return s(),a("div",o,"Organization settings")}const f=t(d,[["render",r]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.62e93c3c.js.map
