import{a as e,A as t,B as i}from"./Text.aa4a1cf1.js";import{A as o}from"./Link.84770fdd.js";import{a as r,A as d}from"./Title.f4855332.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[n]="99a7aa3e-e1de-4ed0-8e93-9de6a5cb3d38",a._sentryDebugIdIdentifier="sentry-dbid-99a7aa3e-e1de-4ed0-8e93-9de6a5cb3d38")}catch{}})();e.Text=t;e.Title=r;e.Paragraph=d;e.Link=o;e.Base=i;e.install=function(a){return a.component(e.name,e),a.component(e.Text.displayName,t),a.component(e.Title.displayName,r),a.component(e.Paragraph.displayName,d),a.component(e.Link.displayName,o),a};
//# sourceMappingURL=index.b57ed653.js.map
