import{f as u,eG as d,d as l,b as f,c as b,w as c,u as s,aq as p,bO as g}from"./outputWidgets.3c34606b.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="e9aba644-2c79-4b0f-9273-3342d5a7de28",t._sentryDebugIdIdentifier="sentry-dbid-e9aba644-2c79-4b0f-9273-3342d5a7de28")}catch{}})();var h={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M832 64H192c-17.7 0-32 14.3-32 32v832c0 17.7 14.3 32 32 32h640c17.7 0 32-14.3 32-32V96c0-17.7-14.3-32-32-32zm-260 72h96v209.9L621.5 312 572 347.4V136zm220 752H232V136h280v296.9c0 3.3 1 6.6 3 9.3a15.9 15.9 0 0022.3 3.7l83.8-59.9 81.4 59.4c2.7 2 6 3.1 9.4 3.1 8.8 0 16-7.2 16-16V136h64v752z"}}]},name:"book",theme:"outlined"};const m=h;function i(t){for(var e=1;e<arguments.length;e++){var n=arguments[e]!=null?Object(arguments[e]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){O(t,a,n[a])})}return t}function O(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var o=function(e,n){var r=i({},e,n.attrs);return u(d,i({},r,{icon:m}),null)};o.displayName="BookOutlined";o.inheritAttrs=!1;const _=o,v=l({__name:"DocsButton",props:{path:{}},setup(t){return(e,n)=>{var r;return f(),b(s(g),{class:"docs-button",href:`https://docs.abstra.io/${(r=e.path)!=null?r:""}`,target:"_blank",type:"link",size:"small"},{icon:c(()=>[u(s(_))]),default:c(()=>[p(" Docs ")]),_:1},8,["href"])}}});export{v as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.36eacc0b.js.map
