import"./outputWidgets.3c34606b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="768565f7-9ac7-47ce-b067-79c7948abbe5",e._sentryDebugIdIdentifier="sentry-dbid-768565f7-9ac7-47ce-b067-79c7948abbe5")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.425cd9cb.js.map
