import"./outputWidgets.3c34606b.js";(function(){try{var x=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(x._sentryDebugIds=x._sentryDebugIds||{},x._sentryDebugIds[e]="76c2c9a3-5061-464f-a534-e130f79fa5e1",x._sentryDebugIdIdentifier="sentry-dbid-76c2c9a3-5061-464f-a534-e130f79fa5e1")}catch{}})();const r=()=>"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(x){const e=Math.random()*16|0;return(x=="x"?e:e&3|8).toString(16)});export{r as u};
//# sourceMappingURL=uuid.b42ed8a7.js.map
