import{d as c,eB as m,u as e,b as d,c as u,ev as y,f as o,w as a,bg as g,aq as p,ex as _,e as x,eD as b}from"./outputWidgets.3c34606b.js";import"./router.56692652.js";import"./index.c3f2d302.js";import{O as w}from"./organization.8d89f32c.js";import{a as h}from"./asyncComputed.8707f293.js";import{a as k}from"./Title.f4855332.js";import{A as B}from"./index.75fc5b93.js";import{A}from"./index.5db26b0a.js";import{A as C}from"./Text.aa4a1cf1.js";import{C as D}from"./Card.b797d31c.js";import"./FormItem.895a8678.js";import"./hasIn.01f4de81.js";import"./index.dd5bce3f.js";import"./index.cf4c23b9.js";import"./record.c46cf28f.js";import"./pubsub.28c1e0e3.js";import"./TabPane.71fe903b.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="660770a3-1c13-4484-9613-fcf0d157fd55",t._sentryDebugIdIdentifier="sentry-dbid-660770a3-1c13-4484-9613-fcf0d157fd55")}catch{}})();const I={key:1},v={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},Q=c({__name:"Billing",setup(t){const n=m().params.organizationId,{loading:f,result:l}=h(()=>w.get(n));return(T,z)=>e(f)?(d(),u(e(g),{key:0})):(d(),y("div",I,[o(e(B),{justify:"space-between",align:"center"},{default:a(()=>[o(e(k),{level:3},{default:a(()=>[p("Current plan")]),_:1}),_("",!0)]),_:1}),o(e(A),{style:{"margin-top":"0"}}),o(e(D),{style:{width:"300px"}},{default:a(()=>{var i,s;return[o(e(C),{type:"secondary"},{default:a(()=>[p("Plan")]),_:1}),x("div",v,b((s=(i=e(l))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{Q as default};
//# sourceMappingURL=Billing.4b3fb748.js.map
