.tooltip-box[data-v-c3a6ca5e]{position:relative;display:inline-block}.tooltip-box:hover .tooltip[data-v-c3a6ca5e]{opacity:1}.tooltip[data-v-c3a6ca5e]{display:flex;justify-content:center;align-items:center;color:#fff;text-align:center;padding:4px 8px;border-radius:3px;font-size:10px;font-weight:500;line-height:12px;cursor:default;user-select:none;width:77px;min-height:20px;opacity:0;transition:opacity 1s;position:absolute;z-index:3;background:#4e596a}.menu-item svg[data-v-38667610]{margin-bottom:-2px}
