import"./outputWidgets.3c34606b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6030e9d4-a043-42bd-8a63-94c1f086ccc6",e._sentryDebugIdIdentifier="sentry-dbid-6030e9d4-a043-42bd-8a63-94c1f086ccc6")}catch{}})();function n(e,t){return e.toLocaleString(void 0,{hour12:!1,timeZoneName:"short",day:"2-digit",month:"2-digit",year:"numeric",hour:"2-digit",minute:"2-digit",second:"2-digit",weekday:"long",...t})}export{n as g};
//# sourceMappingURL=datetime.db16da5f.js.map
