import{U as n,f,O as i,e9 as g,ab as u}from"./outputWidgets.3c34606b.js";import{B as c,b as y}from"./Text.aa4a1cf1.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ff75ce6a-646b-483e-aaa4-903b91f55411",e._sentryDebugIdIdentifier="sentry-dbid-ff75ce6a-646b-483e-aaa4-903b91f55411")}catch{}})();const h=()=>i(y(),["component"]),s=(e,a)=>{let{slots:o,attrs:t}=a;const r=n(n(n({},e),{component:"div"}),t);return f(c,r,o)};s.displayName="ATypographyParagraph";s.inheritAttrs=!1;s.props=h();const v=s;var m=globalThis&&globalThis.__rest||function(e,a){var o={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&a.indexOf(t)<0&&(o[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)a.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(o[t[r]]=e[t[r]]);return o};const P=g(1,2,3,4,5),T=()=>n(n({},i(y(),["component","strong"])),{level:Number}),p=(e,a)=>{let{slots:o,attrs:t}=a;const{level:r=1}=e,b=m(e,["level"]);let l;P.includes(r)?l=`h${r}`:(u(),l="h1");const d=n(n(n({},b),{component:l}),t);return f(c,d,o)};p.displayName="ATypographyTitle";p.inheritAttrs=!1;p.props=T();const w=p;export{v as A,w as a};
//# sourceMappingURL=Title.f4855332.js.map
